# Plone2.0.x migrations

# Plone 1.0.x to Plone 2.0 beta2
import oneX_twoBeta2

# Plone 2.0 base migration
import plone2_base

# Plone 2.0b2 to 2.0b3
import twoBeta2_twoBeta3

# Plone2 RCs
import release_candidates

# Plone2 Final to 2.0.1
import final_two01

# Plone 2.0.4 to 2.0.5
import two04_two05
